@@ -1,20 +1,19 @@
 """Mocking utilities for testing"""
-
-from io import BytesIO
 import json
 import os
 import re
-from unittest.mock import Mock
-from urllib.parse import urlparse, parse_qs
 import uuid
+from io import BytesIO
+from unittest.mock import Mock
+from urllib.parse import parse_qs
+from urllib.parse import urlparse
 
 import pytest
-
+from tornado import web
 from tornado.httpclient import HTTPResponse
 from tornado.httputil import HTTPServerRequest
 from tornado.log import app_log
 from tornado.simple_httpclient import SimpleAsyncHTTPClient
-from tornado import web
 
 RegExpType = type(re.compile('.'))
 
@@ -25,6 +24,7 @@ class MockAsyncHTTPClient(SimpleAsyncHTTPClient):
     Call .add_host to mock requests made to a given host.
 
     """
+
     def initialize(self, *args, **kwargs):
         super().initialize(*args, **kwargs)
         self.hosts = {}
@@ -76,15 +76,21 @@ class MockAsyncHTTPClient(SimpleAsyncHTTPClient):
         elif isinstance(response, int):
             response = HTTPResponse(request=request, code=response)
         elif isinstance(response, bytes):
-            response = HTTPResponse(request=request, code=200,
+            response = HTTPResponse(
+                request=request,
+                code=200,
                 buffer=BytesIO(response),
             )
         elif isinstance(response, str):
-            response = HTTPResponse(request=request, code=200,
+            response = HTTPResponse(
+                request=request,
+                code=200,
                 buffer=BytesIO(response.encode('utf8')),
             )
         elif isinstance(response, (dict, list)):
-            response = HTTPResponse(request=request, code=200,
+            response = HTTPResponse(
+                request=request,
+                code=200,
                 buffer=BytesIO(json.dumps(response).encode('utf8')),
                 headers={'Content-Type': 'application/json'},
             )
@@ -140,7 +146,9 @@ def setup_oauth_mock(
             try:
                 body = json.loads(body)
             except ValueError:
-                return HTTPResponse(request=request, code=400,
+                return HTTPResponse(
+                    request=request,
+                    code=400,
                     reason="Body not JSON: %r" % body,
                 )
             else:
@@ -151,14 +159,20 @@ def setup_oauth_mock(
                 query = request.body.decode('utf8')
             query = parse_qs(query)
             if 'code' not in query:
-                return HTTPResponse(request=request, code=400,
-                    reason="No code in access token request: url=%s, body=%s" % (
-                        request.url, request.body,
-                    )
+                return HTTPResponse(
+                    request=request,
+                    code=400,
+                    reason="No code in access token request: url=%s, body=%s"
+                    % (
+                        request.url,
+                        request.body,
+                    ),
                 )
             code = query['code'][0]
         if code not in oauth_codes:
-            return HTTPResponse(request=request, code=403,
+            return HTTPResponse(
+                request=request,
+                code=403,
                 reason="No such code: %s" % code,
             )
 
@@ -184,11 +198,15 @@ def setup_oauth_mock(
             if 'access_token' in query:
                 token = query['access_token'][0]
             else:
-                return HTTPResponse(request=request, code=403,
+                return HTTPResponse(
+                    request=request,
+                    code=403,
                     reason='Missing Authorization header',
                 )
         if token not in access_tokens:
-            return HTTPResponse(request=request, code=403,
+            return HTTPResponse(
+                request=request,
+                code=403,
                 reason='No such access token: %r' % token,
             )
         return access_tokens.get(token)
@@ -198,10 +216,13 @@ def setup_oauth_mock(
     else:
         hosts = host
     for host in hosts:
-        client.add_host(host, [
-            (access_token_path, access_token),
-            (user_path, get_user),
-        ])
+        client.add_host(
+            host,
+            [
+                (access_token_path, access_token),
+                (user_path, get_user),
+            ],
+        )
 
     def handler_for_user(user):
         """Return a new mock RequestHandler
@@ -215,8 +236,7 @@ def setup_oauth_mock(
         handler.find_user = Mock(return_value=None)
         handler.get_argument = Mock(return_value=code)
         handler.request = HTTPServerRequest(
-            method='GET',
-            uri='https://hub.example.com?code=%s' % code
+            method='GET', uri='https://hub.example.com?code=%s' % code
         )
         handler.hub = Mock(server=Mock(base_url='/hub/'), base_url='/hub/')
         return handler
@@ -229,14 +249,10 @@ def mock_handler(Handler, uri='https://hub.example.com', method='GET', **setting
     application = web.Application(
         hub=Mock(
             base_url='/hub/',
-            server=Mock(
-                base_url='/hub/'
-            ),
+            server=Mock(base_url='/hub/'),
         ),
         cookie_secret=os.urandom(32),
-        db=Mock(
-            rollback=Mock(return_value=None)
-        ),
+        db=Mock(rollback=Mock(return_value=None)),
         **settings
     )
     request = HTTPServerRequest(
